if __name__ == '__main__':
    from .run import run
    run()